'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = TabularCompoundInput;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _CustomCompoundInput = require('./CustomCompoundInput');

var _CustomCompoundInput2 = _interopRequireDefault(_CustomCompoundInput);

var _InputRow = require('./InputRow');

var _InputRow2 = _interopRequireDefault(_InputRow);

var _LabelRow = require('./LabelRow');

var _LabelRow2 = _interopRequireDefault(_LabelRow);

var _labelable = require('../enhancers/labelable');

var _labelable2 = _interopRequireDefault(_labelable);

var _repeatable = require('../enhancers/repeatable');

var _repeatable2 = _interopRequireDefault(_repeatable);

var _isInput = require('../helpers/isInput');

var _isInput2 = _interopRequireDefault(_isInput);

var _normalizeLabel = require('../helpers/normalizeLabel');

var _normalizeLabel2 = _interopRequireDefault(_normalizeLabel);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var BaseComponent = (0, _repeatable2.default)((0, _labelable2.default)(_CustomCompoundInput2.default));

var propTypes = _extends({}, BaseComponent.propTypes, {
  children: _react.PropTypes.node,
  repeating: _react.PropTypes.bool
});

function extractInputs(children) {
  var inputs = [];

  _react2.default.Children.forEach(children, function (child) {
    if ((0, _isInput2.default)(child)) {
      inputs.push(child);
    } else {
      Array.prototype.push.apply(inputs, extractInputs(child.props.children));
    }
  });

  return inputs;
}

function TabularCompoundInput(props) {
  var children = props.children,
      repeating = props.repeating,
      remainingProps = _objectWithoutProperties(props, ['children', 'repeating']);

  var inputs = extractInputs(children);

  var modifiedLabels = inputs.map(function (input) {
    var normalizedLabel = (0, _normalizeLabel2.default)(input.props.label);

    if (!normalizedLabel) {
      return null;
    }

    return _react2.default.cloneElement(normalizedLabel, {
      key: input.props.name
    });
  });

  var modifiedInputs = inputs.map(function (input) {
    return _react2.default.cloneElement(input, {
      key: input.props.name,
      label: undefined,
      embedded: true
    });
  });

  var labelRow = null;

  if (modifiedLabels.some(function (label) {
    return !!label;
  })) {
    labelRow = _react2.default.createElement(
      _LabelRow2.default,
      { embedded: repeating },
      modifiedLabels
    );
  }

  return _react2.default.createElement(
    BaseComponent,
    _extends({}, remainingProps, {
      label: labelRow,
      repeating: repeating
    }),
    _react2.default.createElement(
      _InputRow2.default,
      { embedded: repeating },
      modifiedInputs
    )
  );
}

TabularCompoundInput.propTypes = propTypes;